@@ -41,7 +41,7 @@ pub enum Conflict {
 }
 
 impl Conflict {
-    /// The path that conflicted.
+    /// The path to the blob that for the conflict.
     pub fn path(&self) -> &Path {
         match *self {
             Conflict::Path(ref p) |
@@ -59,11 +59,15 @@ impl PartialEq for Conflict {
 }
 
 #[derive(Debug)]
-/// The result of a merge.
+/// The result of an attempted merge.
 pub enum MergeResult<'a> {
-    /// Information about conflicts within the tree.
+    /// A merge conflict occurred.
     Conflict(Vec<Conflict>),
     /// The merge is ready to be committed.
+    ///
+    /// The command may be executed in order to create the commit from the merged tree. It is
+    /// expected that the relevant `GIT_` environment variables are used on the command to set the
+    /// author and committer information.
     Ready(Command),
 
     #[doc(hidden)]
@@ -76,7 +80,7 @@ pub enum MergeResult<'a> {
 pub type SubmoduleConfig = HashMap<String, HashMap<String, String>>;
 
 // Intermediate type for setting up the work area. Does not include submodules.
-pub struct PreparingGitWorkArea {
+struct PreparingGitWorkArea {
     context: GitContext,
     dir: TempDir,
 }
@@ -217,7 +221,7 @@ impl PreparingGitWorkArea {
     }
 
     // Run a git command in the work area.
-    pub fn git(&self) -> Command {
+    fn git(&self) -> Command {
         let mut git = self.context.git();
 
         git.env("GIT_WORK_TREE", self.work_tree())
@@ -490,8 +494,11 @@ impl PreparedGitWorkArea {
         Ok(conflict_info)
     }
 
-    /// Prepare a command to create a merge commit. It does not actually perform the commit since
-    /// authorship can be provided through the command's environment.
+    /// Prepare a command to create a merge commit.
+    ///
+    /// The merge is performed, but only as a tree object. In order to create the actual commit
+    /// object, a successful merge returns a command which should be executed to create the commit
+    /// object. That commit object should then be stored in a reference using `git update-ref`.
     pub fn setup_merge<'a>(&'a self, bases: &[CommitId], base: &CommitId, topic: &CommitId)
                            -> Result<MergeResult<'a>> {
         debug!(target: "git.workarea",
@@ -539,12 +546,12 @@ impl PreparedGitWorkArea {
         Ok(MergeResult::Ready(commit_tree))
     }
 
-    // The path to the index file for the work tree.
+    // The path to the index file for the work area.
     fn index(&self) -> PathBuf {
         self.dir.path().join("index")
     }
 
-    // The path to the directory for the work tree.
+    // The path to the working directory for the work area.
     fn work_tree(&self) -> PathBuf {
         self.dir.path().join("work")
     }
@@ -555,6 +562,8 @@ impl PreparedGitWorkArea {
     }
 
     /// The submodule configuration for the repository.
+    ///
+    /// This is read from the `.gitmodules` file in the commit (if it exists).
     pub fn submodule_config(&self) -> &SubmoduleConfig {
         &self.submodule_config
     }
